/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizloadtime.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import vip.xiaonuo.biz.modular.bizloadtime.entity.BizLoadTime;
import vip.xiaonuo.biz.modular.bizloadtime.param.BizLoadTimeAddParam;
import vip.xiaonuo.biz.modular.bizloadtime.param.BizLoadTimeEditParam;
import vip.xiaonuo.biz.modular.bizloadtime.param.BizLoadTimeIdParam;
import vip.xiaonuo.biz.modular.bizloadtime.param.BizLoadTimePageParam;

import java.math.BigDecimal;
import java.util.List;

/**
 * 装货时间配置Service接口
 *
 * @author fanzherong
 * @date  2025/05/29 14:55
 **/
public interface BizLoadTimeService extends IService<BizLoadTime> {

    /**
     * 获取装货时间配置分页
     *
     * @author fanzherong
     * @date  2025/05/29 14:55
     */
    Page<BizLoadTime> page(BizLoadTimePageParam bizLoadTimePageParam);

    /**
     * 添加装货时间配置
     *
     * @author fanzherong
     * @date  2025/05/29 14:55
     */
    void add(BizLoadTimeAddParam bizLoadTimeAddParam);

    /**
     * 编辑装货时间配置
     *
     * @author fanzherong
     * @date  2025/05/29 14:55
     */
    void edit(BizLoadTimeEditParam bizLoadTimeEditParam);

    /**
     * 更新已预约次数
     *
     * @author sandy
     * @date  2025/05/29 16:13
     **/
    void editAvailableNumber(String bizLoadTimeId);

    /**
     * 删除装货时间配置
     *
     * @author fanzherong
     * @date  2025/05/29 14:55
     */
    void delete(List<BizLoadTimeIdParam> bizLoadTimeIdParamList);

    /**
     * 获取装货时间配置详情
     *
     * @author fanzherong
     * @date  2025/05/29 14:55
     */
    BizLoadTime detail(BizLoadTimeIdParam bizLoadTimeIdParam);

    // 根据提货时间配置ID和装货点位ID获取装货时间配置
    List<BizLoadTime> search(BizLoadTimePageParam bizLoadTimePageParam);

    // 增加预约次数
    void addAlready(BizLoadTimeIdParam bizLoadTimeIdParam);

    /**
     * 获取装货时间配置详情
     *
     * @author fanzherong
     * @date  2025/05/29 14:55
     **/
    BizLoadTime queryEntity(String id);
}
