/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizloadtime.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.google.common.collect.Lists;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.annotation.Resource;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.biz.modular.bizorderload.entity.BizOrderLoad;
import vip.xiaonuo.biz.modular.bizorderload.service.BizOrderLoadService;
import vip.xiaonuo.biz.modular.customer.entity.BizCustomer;
import vip.xiaonuo.biz.modular.goodsConf.entity.BizGoodsConf;
import vip.xiaonuo.biz.modular.goodsConf.enums.BizGoodsConfEnum;
import vip.xiaonuo.biz.modular.goodsConf.service.BizGoodsConfService;
import vip.xiaonuo.biz.modular.user.mapper.BizUserMapper;
import vip.xiaonuo.biz.modular.user.service.BizUserService;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizloadtime.entity.BizLoadTime;
import vip.xiaonuo.biz.modular.bizloadtime.mapper.BizLoadTimeMapper;
import vip.xiaonuo.biz.modular.bizloadtime.param.BizLoadTimeAddParam;
import vip.xiaonuo.biz.modular.bizloadtime.param.BizLoadTimeEditParam;
import vip.xiaonuo.biz.modular.bizloadtime.param.BizLoadTimeIdParam;
import vip.xiaonuo.biz.modular.bizloadtime.param.BizLoadTimePageParam;
import vip.xiaonuo.biz.modular.bizloadtime.service.BizLoadTimeService;
import vip.xiaonuo.sys.api.SysUserApi;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 装货时间配置Service接口实现类
 *
 * @author fanzherong
 * @date  2025/05/29 14:55
 **/
@Service
public class BizLoadTimeServiceImpl extends ServiceImpl<BizLoadTimeMapper, BizLoadTime> implements BizLoadTimeService {

    @Resource
    private BizUserMapper bizUserMapper;

    @Resource
    private SysUserApi sysUserApi;

    @Resource
    private BizGoodsConfService bizGoodsConfService;

    @Resource
    private BizOrderLoadService bizOrderLoadService;

    @Override
    public Page<BizLoadTime> page(BizLoadTimePageParam bizLoadTimePageParam) {
        QueryWrapper<BizLoadTime> queryWrapper = new QueryWrapper<BizLoadTime>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizLoadTimePageParam.getPointId())) {
            queryWrapper.eq("t.point_id", bizLoadTimePageParam.getPointId());
        }
        if(ObjectUtil.isNotEmpty(bizLoadTimePageParam.getLoadPoint())) {
            queryWrapper.like("p.load_point", bizLoadTimePageParam.getLoadPoint());
        }
        if(ObjectUtil.isNotEmpty(bizLoadTimePageParam.getStartLoadBeginTime()) && ObjectUtil.isNotEmpty(bizLoadTimePageParam.getEndLoadBeginTime())) {
            queryWrapper.between("t.begin_time", bizLoadTimePageParam.getStartLoadBeginTime(), bizLoadTimePageParam.getEndLoadBeginTime());
        }
        if(ObjectUtil.isNotEmpty(bizLoadTimePageParam.getStartLoadEndTime()) && ObjectUtil.isNotEmpty(bizLoadTimePageParam.getEndLoadEndTime())) {
            queryWrapper.between("t.end_time", bizLoadTimePageParam.getStartLoadEndTime(), bizLoadTimePageParam.getEndLoadEndTime());
        }
        queryWrapper.eq("t.DELETE_FLAG", "NOT_DELETE");
        if(ObjectUtil.isAllNotEmpty(bizLoadTimePageParam.getSortField(), bizLoadTimePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizLoadTimePageParam.getSortOrder());
            queryWrapper.orderBy(true, bizLoadTimePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizLoadTimePageParam.getSortField()));
        } else {
            queryWrapper.orderByDesc("t.begin_time");
        }
        return this.baseMapper.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizLoadTimeAddParam bizLoadTimeAddParam) {
        BizLoadTime bizLoadTime = BeanUtil.toBean(bizLoadTimeAddParam, BizLoadTime.class);
        if(!checkBizLoadTime(bizLoadTime)){
            // 当前时间段内的提货配置重叠了
            throw new CommonException("装货配置时间段重叠，请重新选择。");
        }
        this.save(bizLoadTime);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizLoadTimeEditParam bizLoadTimeEditParam) {
        BizLoadTime bizLoadTime = this.queryEntity(bizLoadTimeEditParam.getId());
        if(!checkBizLoadTime(bizLoadTime)){
            // 当前时间段内的提货配置重叠了
            throw new CommonException("装货配置时间段重叠，请重新选择。");
        }
        BeanUtil.copyProperties(bizLoadTimeEditParam, bizLoadTime);
        this.updateById(bizLoadTime);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void editAvailableNumber(String bizLoadTimeId) {
        BizLoadTime bizLoadTime = this.queryEntity(bizLoadTimeId);
        if(null != bizLoadTime){
            /** 原已预约次数 */
            int alreadyNumber = bizLoadTime.getAlreadyNumber();
            alreadyNumber += 1;
            // 更新已提货重量
            bizLoadTime.setAlreadyNumber(alreadyNumber);
            this.updateById(bizLoadTime);
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizLoadTimeIdParam> bizLoadTimeIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizLoadTimeIdParamList, BizLoadTimeIdParam::getId));
    }

    @Override
    public BizLoadTime detail(BizLoadTimeIdParam bizLoadTimeIdParam) {
        return this.queryEntity(bizLoadTimeIdParam.getId());
    }

    @Override
    public List<BizLoadTime> search(BizLoadTimePageParam bizLoadTimePageParam) {
        /** 点位ID */
        String pointId = bizLoadTimePageParam.getPointId();
        /** 提货时间配置ID */
        String goodsConfId = bizLoadTimePageParam.getGoodsConfId();
        // 判断参数是否存在
        if(pointId != null && goodsConfId != null) {
            // 获取提货时间段
            BizGoodsConf bizGoodsConf = bizGoodsConfService.queryEntity(goodsConfId);
            // 开始时间
            Date startTime = bizGoodsConf.getConfStartTime();
            // 结束时间
            Date endTime = bizGoodsConf.getConfEndTime();
            //查询物流订单已经添加过的装卸时段
            List<String> timeIdList = Lists.newArrayList();
            bizOrderLoadService.list(new QueryWrapper<BizOrderLoad>().lambda().
                    eq(BizOrderLoad::getOrderId, bizLoadTimePageParam.getOrderId())).
                    forEach(time->timeIdList.add(time.getLoadTimeId()));
            // 根据时间段和装货点位ID过滤装货时间配置
            List<BizLoadTime> list = this.baseMapper.getSearch(null, pointId, startTime, endTime,timeIdList);
            return list;
        }else{
            return null;
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void addAlready(BizLoadTimeIdParam bizLoadTimeIdParam) {
        BizLoadTime bizLoadTime = this.queryEntity(bizLoadTimeIdParam.getId());
        if(null == bizLoadTime){
            throw new CommonException("装货配置时间段不存在！");
        }
        /** 可约次数 */
        Integer availableNumber = bizLoadTime.getAvailableNumber();
        /** 已约次数 */
        Integer alreadyNumber = bizLoadTime.getAlreadyNumber();

        if(availableNumber <= alreadyNumber){
            throw new CommonException("装货配置时间段已不可预约！");
        }else {
            alreadyNumber += 1;
            bizLoadTime.setAlreadyNumber(alreadyNumber);
            this.updateById(bizLoadTime);
        }
    }

    @Override
    public BizLoadTime queryEntity(String id) {
        BizLoadTime bizLoadTime = this.getById(id);
        if(ObjectUtil.isEmpty(bizLoadTime)) {
            throw new CommonException("装卸时间配置不存在，id值为：{}", id);
        }
        return bizLoadTime;
    }

    // 校验同一个点位的时间段是否有交集
    public Boolean checkBizLoadTime(BizLoadTime bizLoadTime){
        List<BizLoadTime> list = this.baseMapper.getSearch(bizLoadTime.getId(), bizLoadTime.getPointId(), bizLoadTime.getBeginTime(), bizLoadTime.getEndTime(),null);
        if(null != list && list.size() > 0){
            return false;
        }else{
            return true;
        }
    }



}
