/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizloaduser.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.biz.modular.bizloadtime.entity.BizLoadTime;
import vip.xiaonuo.biz.modular.bizsaleorder.entity.BizSaleOrder;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizloaduser.entity.BizLoadUser;
import vip.xiaonuo.biz.modular.bizloaduser.mapper.BizLoadUserMapper;
import vip.xiaonuo.biz.modular.bizloaduser.param.BizLoadUserAddParam;
import vip.xiaonuo.biz.modular.bizloaduser.param.BizLoadUserEditParam;
import vip.xiaonuo.biz.modular.bizloaduser.param.BizLoadUserIdParam;
import vip.xiaonuo.biz.modular.bizloaduser.param.BizLoadUserPageParam;
import vip.xiaonuo.biz.modular.bizloaduser.service.BizLoadUserService;

import java.util.List;

/**
 * 装货点人员信息Service接口实现类
 *
 * @author fanzherong
 * @date  2025/05/29 14:56
 **/
@Service
public class BizLoadUserServiceImpl extends ServiceImpl<BizLoadUserMapper, BizLoadUser> implements BizLoadUserService {

    @Override
    public Page<BizLoadUser> page(BizLoadUserPageParam bizLoadUserPageParam) {
        QueryWrapper<BizLoadUser> queryWrapper = new QueryWrapper<BizLoadUser>().checkSqlInjection();
        //订单编号查询
        if(ObjectUtil.isNotEmpty(bizLoadUserPageParam.getLoadPointId())){
            queryWrapper.like("t.point_id",bizLoadUserPageParam.getLoadPointId());
        }
        queryWrapper.eq("t.delete_flag","NOT_DELETE");
        queryWrapper.orderByDesc("t.create_time");
        return this.getBaseMapper().getPage(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizLoadUserAddParam bizLoadUserAddParam) {
        BizLoadUser bizLoadUser = BeanUtil.toBean(bizLoadUserAddParam, BizLoadUser.class);
        this.save(bizLoadUser);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizLoadUserEditParam bizLoadUserEditParam) {
        BizLoadUser bizLoadUser = this.queryEntity(bizLoadUserEditParam.getId());
        BeanUtil.copyProperties(bizLoadUserEditParam, bizLoadUser);
        this.updateById(bizLoadUser);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizLoadUserIdParam> bizLoadUserIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizLoadUserIdParamList, BizLoadUserIdParam::getId));
    }

    @Override
    public BizLoadUser detail(BizLoadUserIdParam bizLoadUserIdParam) {
        return this.queryEntity(bizLoadUserIdParam.getId());
    }

    @Override
    public BizLoadUser queryEntity(String id) {
        BizLoadUser bizLoadUser = this.getById(id);
        if(ObjectUtil.isEmpty(bizLoadUser)) {
            throw new CommonException("装货点人员信息不存在，id值为：{}", id);
        }
        return bizLoadUser;
    }
}
