/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizorderload.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import jakarta.annotation.Resource;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.biz.modular.bizloadtime.entity.BizLoadTime;
import vip.xiaonuo.biz.modular.bizloadtime.service.BizLoadTimeService;
import vip.xiaonuo.biz.modular.bizorder.entity.BizOrder;
import vip.xiaonuo.biz.modular.bizorder.service.BizOrderService;
import vip.xiaonuo.biz.modular.bizorderconfig.entity.BizOrderConfig;
import vip.xiaonuo.biz.modular.bizorderconfig.service.BizOrderConfigService;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizorderload.entity.BizOrderLoad;
import vip.xiaonuo.biz.modular.bizorderload.mapper.BizOrderLoadMapper;
import vip.xiaonuo.biz.modular.bizorderload.param.BizOrderLoadAddParam;
import vip.xiaonuo.biz.modular.bizorderload.param.BizOrderLoadEditParam;
import vip.xiaonuo.biz.modular.bizorderload.param.BizOrderLoadIdParam;
import vip.xiaonuo.biz.modular.bizorderload.param.BizOrderLoadPageParam;
import vip.xiaonuo.biz.modular.bizorderload.service.BizOrderLoadService;

import java.math.BigDecimal;
import java.util.List;

/**
 * 订单装卸点位Service接口实现类
 *
 * @author fanzherong
 * @date  2025/05/30 14:05
 **/
@Service
public class BizOrderLoadServiceImpl extends ServiceImpl<BizOrderLoadMapper, BizOrderLoad> implements BizOrderLoadService {

    @Resource
    private BizOrderService bizOrderService;
    @Resource
    private BizLoadTimeService bizLoadTimeService;
    @Resource
    private BizOrderConfigService bizOrderConfigService;

    @Override
    public Page<BizOrderLoad> page(BizOrderLoadPageParam bizOrderLoadPageParam) {
        QueryWrapper<BizOrderLoad> queryWrapper = new QueryWrapper<BizOrderLoad>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizOrderLoadPageParam.getOrderId())){
            queryWrapper.eq("bo.id",bizOrderLoadPageParam.getOrderId());
        }
        queryWrapper.eq("bol.delete_flag","NOT_DELETE");
        queryWrapper.orderByDesc("bol.create_time");
        return this.getBaseMapper().getPage(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizOrderLoadAddParam bizOrderLoadAddParam) {
        checkParam(bizOrderLoadAddParam);
        BizOrderLoad bizOrderLoad = BeanUtil.toBean(bizOrderLoadAddParam, BizOrderLoad.class);
        this.save(bizOrderLoad);

        //修改订单状态
        BizOrder bizOrder = bizOrderService.queryEntity(bizOrderLoadAddParam.getOrderId());
        bizOrder.setOrderStatus("3");
        bizOrderService.updateById(bizOrder);
    }

    public void checkParam(BizOrderLoadAddParam bizOrderLoadAddParam){
        QueryWrapper<BizOrderLoad> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(BizOrderLoad::getOrderId,bizOrderLoadAddParam.getOrderId()).
                eq(BizOrderLoad::getLoadPointId,bizOrderLoadAddParam.getLoadPointId()).
                eq(BizOrderLoad::getLoadTimeId,bizOrderLoadAddParam.getLoadTimeId());
        long count = this.count(queryWrapper);
        if(count>0){
            throw new CommonException("装卸点位和时间已经添加过！");
        }

        //判断物流订单提货时段的总预约次数
        BizOrder bizOrder = bizOrderService.getById(bizOrderLoadAddParam.getOrderId());
        if(ObjectUtil.isNotNull(bizOrder)){
            QueryWrapper<BizOrderLoad> wrapper = new QueryWrapper<>();
            wrapper.eq("bol.delete_flag","NOT_DELETE");
            wrapper.eq("blt.delete_flag","NOT_DELETE");
            wrapper.eq("bol.order_id",bizOrder.getId());
            Integer avaNumber = this.getBaseMapper().getAvaNumber(wrapper);
            Integer avaCount = 0;
            Integer orderNumber = 0;
            if(ObjectUtil.isNotEmpty(bizOrderLoadAddParam.getLoadTimeId())){
                BizLoadTime bizLoadTime = bizLoadTimeService.getById(bizOrderLoadAddParam.getLoadTimeId());
                if(ObjectUtil.isNotNull(bizLoadTime)){
                    avaCount = bizLoadTime.getAvailableNumber();
                }
                //查询物流订单申请数量
                BizOrderConfig bizOrderConfig = bizOrderConfigService.getOne(new QueryWrapper<BizOrderConfig>().lambda().
                        eq(BizOrderConfig::getOrderId, bizOrder.getId()).
                        last("limit 1"));
                if(ObjectUtil.isNotNull(bizOrderConfig)){
                    orderNumber = bizOrderConfig.getApplyNumber();
                }
                if(avaCount+avaNumber > orderNumber){
                    throw new CommonException("物流订单申请预约数量："+bizOrderConfig.getApplyNumber()+",装卸时段已添加预约："+avaNumber+",还可添加预约："+(orderNumber-avaNumber));
                }
            }
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizOrderLoadEditParam bizOrderLoadEditParam) {
        BizOrderLoad bizOrderLoad = this.queryEntity(bizOrderLoadEditParam.getId());
        BeanUtil.copyProperties(bizOrderLoadEditParam, bizOrderLoad);
        this.updateById(bizOrderLoad);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizOrderLoadIdParam> bizOrderLoadIdParamList) {
        // 执行删除
        //this.removeByIds(CollStreamUtil.toList(bizOrderLoadIdParamList, BizOrderLoadIdParam::getId));
        String orderId = null;
        for(BizOrderLoadIdParam bizOrderLoadIdParam:bizOrderLoadIdParamList){
            BizOrderLoad bizOrderLoad = this.queryEntity(bizOrderLoadIdParam.getId());
            orderId = bizOrderLoad.getOrderId();
            BizLoadTime bizLoadTime = bizLoadTimeService.getById(bizOrderLoad.getLoadTimeId());
            if(ObjectUtil.isNotNull(bizLoadTime)){
                if(ObjectUtil.isNotEmpty(bizLoadTime.getAlreadyNumber()) && bizLoadTime.getAlreadyNumber()>0){
                    throw new CommonException("已经添加过预约，不可删除！");
                }
            }
            this.removeById(bizOrderLoad);
        }
        if(ObjectUtil.isNotEmpty(orderId)){
            //查询订单下是否有装货时间
            long count = this.count(new QueryWrapper<BizOrderLoad>().lambda().eq(BizOrderLoad::getOrderId, orderId));
            if(count==0){
                BizOrder bizOrder = bizOrderService.getById(orderId);
                if(ObjectUtil.isNotNull(bizOrder)){
                    bizOrder.setOrderStatus("8");
                    bizOrderService.updateById(bizOrder);
                }
            }

        }
    }

    @Override
    public BizOrderLoad detail(BizOrderLoadIdParam bizOrderLoadIdParam) {
        return this.queryEntity(bizOrderLoadIdParam.getId());
    }

    @Override
    public BizOrderLoad queryEntity(String id) {
        BizOrderLoad bizOrderLoad = this.getById(id);
        if(ObjectUtil.isEmpty(bizOrderLoad)) {
            throw new CommonException("订单装卸点位不存在，id值为：{}", id);
        }
        return bizOrderLoad;
    }

    @Override
    public List<BizOrderLoad> getLoadTimeList(BizOrderLoadPageParam bizOrderLoadPageParam) {
        QueryWrapper<BizOrderLoad> queryWrapper = new QueryWrapper<BizOrderLoad>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizOrderLoadPageParam.getOrderId())){
            queryWrapper.eq("bo.id",bizOrderLoadPageParam.getOrderId());
        }
        if(ObjectUtil.isNotEmpty(bizOrderLoadPageParam.getLoadPointId())){
            queryWrapper.eq("bol.load_point_id",bizOrderLoadPageParam.getLoadPointId());
        }
        String date = DateUtil.format(DateUtil.date(), "yyyy-MM-dd HH:mm:ss");
        queryWrapper.and(wrapper-> wrapper.le("blt.begin_time",date).gt("blt.end_time",date).or().
                ge("blt.begin_time",date));
        queryWrapper.eq("bol.delete_flag","NOT_DELETE");
        queryWrapper.orderByDesc("bol.create_time");
        List<BizOrderLoad> loadList = this.getBaseMapper().getPage(queryWrapper);
        return loadList;
    }

    @Override
    public List<BizOrderLoad> getPointList(BizOrderLoadPageParam bizOrderLoadPageParam) {
        QueryWrapper<BizOrderLoad> queryWrapper = new QueryWrapper<BizOrderLoad>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizOrderLoadPageParam.getOrderId())){
            queryWrapper.eq("bol.order_id",bizOrderLoadPageParam.getOrderId());
        }
        queryWrapper.eq("bol.delete_flag","NOT_DELETE");
        queryWrapper.orderByDesc("bol.create_time");
        queryWrapper.groupBy("bol.load_point_id");
        List<BizOrderLoad> pointList = this.getBaseMapper().getPointList(queryWrapper);
        return pointList;
    }
}
