/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizprocess.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.bizprocess.entity.BizProcessNode;
import vip.xiaonuo.biz.modular.bizprocess.param.BizProcessNodeAddParam;
import vip.xiaonuo.biz.modular.bizprocess.param.BizProcessNodeEditParam;
import vip.xiaonuo.biz.modular.bizprocess.param.BizProcessNodeIdParam;
import vip.xiaonuo.biz.modular.bizprocess.param.BizProcessNodePageParam;
import vip.xiaonuo.biz.modular.bizprocess.service.BizProcessNodeService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 工序节点控制器
 *
 * @author fanzherong
 * @date  2025/05/29 15:09
 */
@Tag(name = "工序节点控制器")
@RestController
@Validated
public class BizProcessNodeController {

    @Resource
    private BizProcessNodeService bizProcessNodeService;

    /**
     * 获取工序节点分页
     *
     * @author fanzherong
     * @date  2025/05/29 15:09
     */
    @Operation(summary = "获取工序节点分页")
    @SaCheckPermission("/biz/bizprocessnode/page")
    @GetMapping("/biz/bizprocessnode/page")
    public CommonResult<Page<BizProcessNode>> page(BizProcessNodePageParam bizProcessNodePageParam) {
        return CommonResult.data(bizProcessNodeService.page(bizProcessNodePageParam));
    }

    /**
     * 添加工序节点
     *
     * @author fanzherong
     * @date  2025/05/29 15:09
     */
    @Operation(summary = "添加工序节点")
    @CommonLog("添加工序节点")
    @PostMapping("/biz/bizprocessnode/add")
    public CommonResult<String> add(@RequestBody @Valid BizProcessNodeAddParam bizProcessNodeAddParam) {
        bizProcessNodeService.add(bizProcessNodeAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑工序节点
     *
     * @author fanzherong
     * @date  2025/05/29 15:09
     */
    @Operation(summary = "编辑工序节点")
    @CommonLog("编辑工序节点")
    @PostMapping("/biz/bizprocessnode/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizProcessNodeEditParam bizProcessNodeEditParam) {
        bizProcessNodeService.edit(bizProcessNodeEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除工序节点
     *
     * @author fanzherong
     * @date  2025/05/29 15:09
     */
    @Operation(summary = "删除工序节点")
    @CommonLog("删除工序节点")
    @PostMapping("/biz/bizprocessnode/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizProcessNodeIdParam> bizProcessNodeIdParamList) {
        bizProcessNodeService.delete(bizProcessNodeIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取工序节点详情
     *
     * @author fanzherong
     * @date  2025/05/29 15:09
     */
    @Operation(summary = "获取工序节点详情")
    @GetMapping("/biz/bizprocessnode/detail")
    public CommonResult<BizProcessNode> detail(@Valid BizProcessNodeIdParam bizProcessNodeIdParam) {
        return CommonResult.data(bizProcessNodeService.detail(bizProcessNodeIdParam));
    }
}
