/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizprocess.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.biz.modular.bizprocess.entity.BizProcess;
import vip.xiaonuo.biz.modular.bizprocess.enums.BizProcessNodeEnum;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizprocess.entity.BizProcessNode;
import vip.xiaonuo.biz.modular.bizprocess.mapper.BizProcessNodeMapper;
import vip.xiaonuo.biz.modular.bizprocess.param.BizProcessNodeAddParam;
import vip.xiaonuo.biz.modular.bizprocess.param.BizProcessNodeEditParam;
import vip.xiaonuo.biz.modular.bizprocess.param.BizProcessNodeIdParam;
import vip.xiaonuo.biz.modular.bizprocess.param.BizProcessNodePageParam;
import vip.xiaonuo.biz.modular.bizprocess.service.BizProcessNodeService;

import java.util.List;

/**
 * 工序节点Service接口实现类
 *
 * @author fanzherong
 * @date  2025/05/29 15:09
 **/
@Service
public class BizProcessNodeServiceImpl extends ServiceImpl<BizProcessNodeMapper, BizProcessNode> implements BizProcessNodeService {

    @Override
    public Page<BizProcessNode> page(BizProcessNodePageParam bizProcessNodePageParam) {
        QueryWrapper<BizProcessNode> queryWrapper = new QueryWrapper<BizProcessNode>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizProcessNodePageParam.getProcessId())){
            queryWrapper.lambda().like(BizProcessNode::getProcessId, bizProcessNodePageParam.getProcessId());
        }
        if(ObjectUtil.isAllNotEmpty(bizProcessNodePageParam.getSortField(), bizProcessNodePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizProcessNodePageParam.getSortOrder());
            queryWrapper.orderBy(true, bizProcessNodePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizProcessNodePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(BizProcessNode::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizProcessNodeAddParam bizProcessNodeAddParam) {
        //查询名称是否添加过
        long countName = this.count(new QueryWrapper<BizProcessNode>().lambda().eq(BizProcessNode::getNodeName, bizProcessNodeAddParam.getNodeName())
                                                                            .eq(BizProcessNode::getProcessId, bizProcessNodeAddParam.getProcessId())
                                                                            .eq(BizProcessNode::getDeleteFlag, BizProcessNodeEnum.NOT_DELETE.getValue()));
        if(countName>0){
            throw new CommonException("生产工序节点名称已存在！");
        }
        BizProcessNode bizProcessNode = BeanUtil.toBean(bizProcessNodeAddParam, BizProcessNode.class);
        this.save(bizProcessNode);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizProcessNodeEditParam bizProcessNodeEditParam) {
        //查询名称是否添加过
        long countName = this.count(new QueryWrapper<BizProcessNode>().lambda().eq(BizProcessNode::getNodeName, bizProcessNodeEditParam.getNodeName())
                                                        .eq(BizProcessNode::getProcessId, bizProcessNodeEditParam.getProcessId())
                                                        .ne(BizProcessNode::getId, bizProcessNodeEditParam.getId())
                                                        .eq(BizProcessNode::getDeleteFlag, BizProcessNodeEnum.NOT_DELETE.getValue()));
        if(countName>0){
            throw new CommonException("生产工序节点名称已存在！");
        }
        BizProcessNode bizProcessNode = this.queryEntity(bizProcessNodeEditParam.getId());
        BeanUtil.copyProperties(bizProcessNodeEditParam, bizProcessNode);
        this.updateById(bizProcessNode);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizProcessNodeIdParam> bizProcessNodeIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizProcessNodeIdParamList, BizProcessNodeIdParam::getId));
    }

    @Override
    public BizProcessNode detail(BizProcessNodeIdParam bizProcessNodeIdParam) {
        return this.queryEntity(bizProcessNodeIdParam.getId());
    }

    @Override
    public BizProcessNode queryEntity(String id) {
        BizProcessNode bizProcessNode = this.getById(id);
        if(ObjectUtil.isEmpty(bizProcessNode)) {
            throw new CommonException("工序节点不存在，id值为：{}", id);
        }
        return bizProcessNode;
    }
}
