/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizservicecustomer.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.biz.modular.bizservicecustomer.param.*;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.bizservicecustomer.entity.BizServiceCustomerFlow;
import vip.xiaonuo.biz.modular.bizservicecustomer.service.BizServiceCustomerFlowService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 服务客户资金流水控制器
 *
 * @author fanzherong
 * @date  2025/05/29 14:40
 */
@Tag(name = "服务客户资金流水控制器")
@RestController
@Validated
public class BizServiceCustomerFlowController {

    @Resource
    private BizServiceCustomerFlowService bizServiceCustomerFlowService;

    /**
     * 获取服务客户资金流水分页
     *
     * @author fanzherong
     * @date  2025/05/29 14:40
     */
    @Operation(summary = "获取服务客户资金流水分页")
    @GetMapping("/biz/bizservicecustomerflow/page")
    public CommonResult<Page<BizServiceCustomerFlow>> page(BizServiceCustomerFlowPageParam bizServiceCustomerFlowPageParam) {
        return CommonResult.data(bizServiceCustomerFlowService.page(bizServiceCustomerFlowPageParam));
    }

    /**
     * 添加服务客户资金流水
     *
     * @author fanzherong
     * @date  2025/05/29 14:40
     */
    @Operation(summary = "添加服务客户资金流水")
    @CommonLog("添加服务客户资金流水")
    @SaCheckPermission("/biz/bizservicecustomerflow/add")
    @PostMapping("/biz/bizservicecustomerflow/add")
    public CommonResult<String> add(@RequestBody @Valid BizServiceCustomerFlowAddParam bizServiceCustomerFlowAddParam) {
        bizServiceCustomerFlowService.add(bizServiceCustomerFlowAddParam);
        return CommonResult.ok();
    }

    /**
     * 取消服务客户资金流水
     *
     * @author sandy
     * @date  2025/06/03 17:40
     */
    @Operation(summary = "取消服务客户资金流水")
    @CommonLog("取消服务客户资金流水")
    @SaCheckPermission("/biz/bizservicecustomerflow/cancel")
    @PostMapping("/biz/bizservicecustomerflow/cancel")
    public CommonResult<String> cancel(@RequestBody @Valid BizServiceCustomerFlowCancelParam bizServiceCustomerFlowCancelParam) {
        bizServiceCustomerFlowService.cancel(bizServiceCustomerFlowCancelParam);
        return CommonResult.ok();
    }

    /**
     * 编辑服务客户资金流水
     *
     * @author fanzherong
     * @date  2025/05/29 14:40
     */
    @Operation(summary = "编辑服务客户资金流水")
    @CommonLog("编辑服务客户资金流水")
    @SaCheckPermission("/biz/bizservicecustomerflow/edit")
    @PostMapping("/biz/bizservicecustomerflow/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizServiceCustomerFlowEditParam bizServiceCustomerFlowEditParam) {
        bizServiceCustomerFlowService.edit(bizServiceCustomerFlowEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除服务客户资金流水
     *
     * @author fanzherong
     * @date  2025/05/29 14:40
     */
    @Operation(summary = "删除服务客户资金流水")
    @CommonLog("删除服务客户资金流水")
    @SaCheckPermission("/biz/bizservicecustomerflow/delete")
    @PostMapping("/biz/bizservicecustomerflow/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizServiceCustomerFlowIdParam> bizServiceCustomerFlowIdParamList) {
        bizServiceCustomerFlowService.delete(bizServiceCustomerFlowIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取服务客户资金流水详情
     *
     * @author fanzherong
     * @date  2025/05/29 14:40
     */
    @Operation(summary = "获取服务客户资金流水详情")
    @GetMapping("/biz/bizservicecustomerflow/detail")
    public CommonResult<BizServiceCustomerFlow> detail(@Valid BizServiceCustomerFlowIdParam bizServiceCustomerFlowIdParam) {
        return CommonResult.data(bizServiceCustomerFlowService.detail(bizServiceCustomerFlowIdParam));
    }

    /**
     * 服务客户资金锁定金额确定扣费
     *
     * @author sandy
     * @date  2025/06/03 17:40
     */
    @Operation(summary = "服务客户资金锁定金额确定扣费")
    @CommonLog("服务客户资金锁定金额确定扣费")
    @SaCheckPermission("/biz/bizservicecustomerflow/lockConsume")
    @PostMapping("/biz/bizservicecustomerflow/lockConsume")
    public CommonResult<String> lockConsume(@RequestBody @Valid BizServiceCustomerAccountLockParam bizServiceCustomerFlowLockParam) {
        bizServiceCustomerFlowService.lockConsume(bizServiceCustomerFlowLockParam);
        return CommonResult.ok();
    }
}
