/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizservicecustomer.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.biz.modular.bizservicecustomer.enums.BizServiceCustomerAccountEnum;
import vip.xiaonuo.biz.modular.bizservicecustomer.param.*;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizservicecustomer.entity.BizServiceCustomerAccount;
import vip.xiaonuo.biz.modular.bizservicecustomer.mapper.BizServiceCustomerAccountMapper;
import vip.xiaonuo.biz.modular.bizservicecustomer.service.BizServiceCustomerAccountService;

import java.math.BigDecimal;
import java.util.List;

/**
 * 服务客户账号管理Service接口实现类
 *
 * @author fanzherong
 * @date  2025/05/29 14:39
 **/
@Service
public class BizServiceCustomerAccountServiceImpl extends ServiceImpl<BizServiceCustomerAccountMapper, BizServiceCustomerAccount> implements BizServiceCustomerAccountService {

    @Override
    public Page<BizServiceCustomerAccount> page(BizServiceCustomerAccountPageParam bizServiceCustomerAccountPageParam) {
        QueryWrapper<BizServiceCustomerAccount> queryWrapper = new QueryWrapper<BizServiceCustomerAccount>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizServiceCustomerAccountPageParam.getServiceCustomerId())){
            queryWrapper.lambda().like(BizServiceCustomerAccount::getServiceCustomerId, bizServiceCustomerAccountPageParam.getServiceCustomerId());
        }
        if(ObjectUtil.isAllNotEmpty(bizServiceCustomerAccountPageParam.getSortField(), bizServiceCustomerAccountPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizServiceCustomerAccountPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizServiceCustomerAccountPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizServiceCustomerAccountPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(BizServiceCustomerAccount::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizServiceCustomerAccountAddParam bizServiceCustomerAccountAddParam) {
        //查询名称是否添加过
        long countName = this.count(new QueryWrapper<BizServiceCustomerAccount>().lambda().eq(BizServiceCustomerAccount::getLoginAccount, bizServiceCustomerAccountAddParam.getLoginAccount())
                                                                                .eq(BizServiceCustomerAccount::getDeleteFlag, BizServiceCustomerAccountEnum.NOT_DELETE.getValue()));
        BizServiceCustomerAccount bizServiceCustomerAccount = BeanUtil.toBean(bizServiceCustomerAccountAddParam, BizServiceCustomerAccount.class);
        this.save(bizServiceCustomerAccount);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizServiceCustomerAccountEditParam bizServiceCustomerAccountEditParam) {
        //查询名称是否添加过
        long countName = this.count(new QueryWrapper<BizServiceCustomerAccount>().lambda().eq(BizServiceCustomerAccount::getLoginAccount, bizServiceCustomerAccountEditParam.getLoginAccount())
                                                                                .ne(BizServiceCustomerAccount::getId, bizServiceCustomerAccountEditParam.getId())
                                                                                .eq(BizServiceCustomerAccount::getDeleteFlag, BizServiceCustomerAccountEnum.NOT_DELETE.getValue()));
        BizServiceCustomerAccount bizServiceCustomerAccount = this.queryEntity(bizServiceCustomerAccountEditParam.getId());
        BeanUtil.copyProperties(bizServiceCustomerAccountEditParam, bizServiceCustomerAccount);
        this.updateById(bizServiceCustomerAccount);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizServiceCustomerAccountIdParam> bizServiceCustomerAccountIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizServiceCustomerAccountIdParamList, BizServiceCustomerAccountIdParam::getId));
    }

    @Override
    public BizServiceCustomerAccount detail(BizServiceCustomerAccountIdParam bizServiceCustomerAccountIdParam) {
        return this.queryEntity(bizServiceCustomerAccountIdParam.getId());
    }

    @Override
    public BizServiceCustomerAccount queryEntity(String id) {
        BizServiceCustomerAccount bizServiceCustomerAccount = this.getById(id);
        if(ObjectUtil.isEmpty(bizServiceCustomerAccount)) {
            throw new CommonException("服务客户账号管理不存在，id值为：{}", id);
        }
        return bizServiceCustomerAccount;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void lock(BizServiceCustomerAccountLockParam bizServiceCustomerFlowLockParam){
        BizServiceCustomerAccount bizServiceCustomerAccount = this.queryEntity(bizServiceCustomerFlowLockParam.getId());
        BigDecimal lockAmount = bizServiceCustomerFlowLockParam.getLockAmount();
        /** 锁定金额（占用金额） */
        BigDecimal lockAmountOld = bizServiceCustomerAccount.getLockAmount();
        /** 可用余额（账户余额） */
        BigDecimal accountAmount = bizServiceCustomerAccount.getAccountAmount();

        // 添加锁定金额
        bizServiceCustomerAccount.setLockAmount(lockAmountOld.add(lockAmount));
        // 余额扣减
        bizServiceCustomerAccount.setAccountAmount(accountAmount.subtract(lockAmount));
        this.updateById(bizServiceCustomerAccount);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void unlock(BizServiceCustomerAccountLockParam bizServiceCustomerFlowLockParam){
        BizServiceCustomerAccount bizServiceCustomerAccount = this.queryEntity(bizServiceCustomerFlowLockParam.getId());
        BigDecimal lockAmount = bizServiceCustomerFlowLockParam.getLockAmount();
        /** 锁定金额（占用金额） */
        BigDecimal lockAmountOld = bizServiceCustomerAccount.getLockAmount();
        /** 可用余额（账户余额） */
        BigDecimal accountAmount = bizServiceCustomerAccount.getAccountAmount();

        // 取消锁定金额
        bizServiceCustomerAccount.setLockAmount(lockAmountOld.subtract(lockAmount));
        // 余额恢复
        bizServiceCustomerAccount.setAccountAmount(accountAmount.add(lockAmount));
        this.updateById(bizServiceCustomerAccount);
    }

}
