/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizsupplier.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.bizsupplier.entity.BizSupplierTransport;
import vip.xiaonuo.biz.modular.bizsupplier.param.BizSupplierTransportAddParam;
import vip.xiaonuo.biz.modular.bizsupplier.param.BizSupplierTransportEditParam;
import vip.xiaonuo.biz.modular.bizsupplier.param.BizSupplierTransportIdParam;
import vip.xiaonuo.biz.modular.bizsupplier.param.BizSupplierTransportPageParam;
import vip.xiaonuo.biz.modular.bizsupplier.service.BizSupplierTransportService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 供应商运输管理控制器
 *
 * @author fanzherong
 * @date  2025/05/29 14:47
 */
@Tag(name = "供应商运输管理控制器")
@RestController
@Validated
public class BizSupplierTransportController {

    @Resource
    private BizSupplierTransportService bizSupplierTransportService;

    /**
     * 获取供应商运输管理分页
     *
     * @author fanzherong
     * @date  2025/05/29 14:47
     */
    @Operation(summary = "获取供应商运输管理分页")
    @GetMapping("/biz/bizsuppliertransport/page")
    public CommonResult<Page<BizSupplierTransport>> page(BizSupplierTransportPageParam bizSupplierTransportPageParam) {
        return CommonResult.data(bizSupplierTransportService.page(bizSupplierTransportPageParam));
    }

    /**
     * 添加供应商运输管理
     *
     * @author fanzherong
     * @date  2025/05/29 14:47
     */
    @Operation(summary = "添加供应商运输管理")
    @CommonLog("添加供应商运输管理")
    @SaCheckPermission("/biz/bizsuppliertransport/add")
    @PostMapping("/biz/bizsuppliertransport/add")
    public CommonResult<String> add(@RequestBody @Valid BizSupplierTransportAddParam bizSupplierTransportAddParam) {
        bizSupplierTransportService.add(bizSupplierTransportAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑供应商运输管理
     *
     * @author fanzherong
     * @date  2025/05/29 14:47
     */
    @Operation(summary = "编辑供应商运输管理")
    @CommonLog("编辑供应商运输管理")
    @SaCheckPermission("/biz/bizsuppliertransport/edit")
    @PostMapping("/biz/bizsuppliertransport/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizSupplierTransportEditParam bizSupplierTransportEditParam) {
        bizSupplierTransportService.edit(bizSupplierTransportEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除供应商运输管理
     *
     * @author fanzherong
     * @date  2025/05/29 14:47
     */
    @Operation(summary = "删除供应商运输管理")
    @CommonLog("删除供应商运输管理")
    @SaCheckPermission("/biz/bizsuppliertransport/delete")
    @PostMapping("/biz/bizsuppliertransport/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizSupplierTransportIdParam> bizSupplierTransportIdParamList) {
        bizSupplierTransportService.delete(bizSupplierTransportIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取供应商运输管理详情
     *
     * @author fanzherong
     * @date  2025/05/29 14:47
     */
    @Operation(summary = "获取供应商运输管理详情")
    @GetMapping("/biz/bizsuppliertransport/detail")
    public CommonResult<BizSupplierTransport> detail(@Valid BizSupplierTransportIdParam bizSupplierTransportIdParam) {
        return CommonResult.data(bizSupplierTransportService.detail(bizSupplierTransportIdParam));
    }
}
