/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizsupplier.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.biz.modular.bizloadpoint.entity.BizLoadPoint;
import vip.xiaonuo.biz.modular.bizsupplier.entity.BizSupplier;
import vip.xiaonuo.biz.modular.bizsupplier.enums.BizSupplierAccountEnum;
import vip.xiaonuo.biz.modular.customer.entity.BizCustomer;
import vip.xiaonuo.biz.modular.customer.entity.BizCustomerAccount;
import vip.xiaonuo.biz.modular.customer.enums.BizCustomerAccountEnum;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizsupplier.entity.BizSupplierAccount;
import vip.xiaonuo.biz.modular.bizsupplier.mapper.BizSupplierAccountMapper;
import vip.xiaonuo.biz.modular.bizsupplier.param.BizSupplierAccountAddParam;
import vip.xiaonuo.biz.modular.bizsupplier.param.BizSupplierAccountEditParam;
import vip.xiaonuo.biz.modular.bizsupplier.param.BizSupplierAccountIdParam;
import vip.xiaonuo.biz.modular.bizsupplier.param.BizSupplierAccountPageParam;
import vip.xiaonuo.biz.modular.bizsupplier.service.BizSupplierAccountService;

import java.util.List;

/**
 * 供应商账号信息Service接口实现类
 *
 * @author fanzherong
 * @date  2025/05/29 14:47
 **/
@Service
public class BizSupplierAccountServiceImpl extends ServiceImpl<BizSupplierAccountMapper, BizSupplierAccount> implements BizSupplierAccountService {

    @Override
    public Page<BizSupplierAccount> page(BizSupplierAccountPageParam bizSupplierAccountPageParam) {
        QueryWrapper<BizSupplierAccount> queryWrapper = new QueryWrapper<BizSupplierAccount>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizSupplierAccountPageParam.getSupplierId())){
            queryWrapper.lambda().like(BizSupplierAccount::getSupplierId,bizSupplierAccountPageParam.getSupplierId());
        }
        queryWrapper.lambda().eq(BizSupplierAccount::getDeleteFlag, "NOT_DELETE");
        if(ObjectUtil.isAllNotEmpty(bizSupplierAccountPageParam.getSortField(), bizSupplierAccountPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizSupplierAccountPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizSupplierAccountPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizSupplierAccountPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(BizSupplierAccount::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizSupplierAccountAddParam bizSupplierAccountAddParam) {
        //查询名称是否添加过
        long countName = this.count(new QueryWrapper<BizSupplierAccount>().lambda().eq(BizSupplierAccount::getSupplierAccount, bizSupplierAccountAddParam.getSupplierAccount())
                                                                                    .eq(BizSupplierAccount::getDeleteFlag, BizSupplierAccountEnum.NOT_DELETE.getValue()));
        if(countName>0){
            throw new CommonException("供应商账号已存在！");
        }
        BizSupplierAccount bizSupplierAccount = BeanUtil.toBean(bizSupplierAccountAddParam, BizSupplierAccount.class);
        this.save(bizSupplierAccount);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizSupplierAccountEditParam bizSupplierAccountEditParam) {
        //查询名称是否添加过
        long countName = this.count(new QueryWrapper<BizSupplierAccount>().lambda().eq(BizSupplierAccount::getSupplierAccount, bizSupplierAccountEditParam.getSupplierAccount())
                                                                                    .ne(BizSupplierAccount::getId, bizSupplierAccountEditParam.getId())
                                                                                    .eq(BizSupplierAccount::getDeleteFlag, BizSupplierAccountEnum.NOT_DELETE.getValue()));
        if(countName>0){
            throw new CommonException("供应商账号已存在！");
        }
        BizSupplierAccount bizSupplierAccount = this.queryEntity(bizSupplierAccountEditParam.getId());
        BeanUtil.copyProperties(bizSupplierAccountEditParam, bizSupplierAccount);
        this.updateById(bizSupplierAccount);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizSupplierAccountIdParam> bizSupplierAccountIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizSupplierAccountIdParamList, BizSupplierAccountIdParam::getId));
    }

    @Override
    public BizSupplierAccount detail(BizSupplierAccountIdParam bizSupplierAccountIdParam) {
        return this.queryEntity(bizSupplierAccountIdParam.getId());
    }

    @Override
    public BizSupplierAccount queryEntity(String id) {
        BizSupplierAccount bizSupplierAccount = this.getById(id);
        if(ObjectUtil.isEmpty(bizSupplierAccount)) {
            throw new CommonException("供应商账号信息不存在，id值为：{}", id);
        }
        return bizSupplierAccount;
    }
}
