/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizsupplier.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.biz.modular.bizsupplier.entity.BizSupplier;
import vip.xiaonuo.biz.modular.bizsupplier.entity.BizSupplierAccount;
import vip.xiaonuo.biz.modular.bizsupplier.enums.BizSupplierAccountEnum;
import vip.xiaonuo.biz.modular.bizsupplier.enums.BizSupplierTransportEnum;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizsupplier.entity.BizSupplierTransport;
import vip.xiaonuo.biz.modular.bizsupplier.mapper.BizSupplierTransportMapper;
import vip.xiaonuo.biz.modular.bizsupplier.param.BizSupplierTransportAddParam;
import vip.xiaonuo.biz.modular.bizsupplier.param.BizSupplierTransportEditParam;
import vip.xiaonuo.biz.modular.bizsupplier.param.BizSupplierTransportIdParam;
import vip.xiaonuo.biz.modular.bizsupplier.param.BizSupplierTransportPageParam;
import vip.xiaonuo.biz.modular.bizsupplier.service.BizSupplierTransportService;

import java.util.List;

/**
 * 供应商运输管理Service接口实现类
 *
 * @author fanzherong
 * @date  2025/05/29 14:47
 **/
@Service
public class BizSupplierTransportServiceImpl extends ServiceImpl<BizSupplierTransportMapper, BizSupplierTransport> implements BizSupplierTransportService {

    @Override
    public Page<BizSupplierTransport> page(BizSupplierTransportPageParam bizSupplierTransportPageParam) {
        QueryWrapper<BizSupplierTransport> queryWrapper = new QueryWrapper<BizSupplierTransport>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizSupplierTransportPageParam.getSupplierId())){
            queryWrapper.lambda().like(BizSupplierTransport::getSupplierId,bizSupplierTransportPageParam.getSupplierId());
        }
        queryWrapper.lambda().eq(BizSupplierTransport::getDeleteFlag, "NOT_DELETE");
        if(ObjectUtil.isAllNotEmpty(bizSupplierTransportPageParam.getSortField(), bizSupplierTransportPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizSupplierTransportPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizSupplierTransportPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizSupplierTransportPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(BizSupplierTransport::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizSupplierTransportAddParam bizSupplierTransportAddParam) {
        //查询名称是否添加过
        long countName = this.count(new QueryWrapper<BizSupplierTransport>().lambda().eq(BizSupplierTransport::getTransportNo, bizSupplierTransportAddParam.getTransportNo())
                                                                                    .eq(BizSupplierTransport::getSupplierId, bizSupplierTransportAddParam.getSupplierId())
                                                                                    .eq(BizSupplierTransport::getDeleteFlag, BizSupplierTransportEnum.NOT_DELETE.getValue()));
        if(countName>0){
            throw new CommonException("供应商运输号已存在！");
        }
        BizSupplierTransport bizSupplierTransport = BeanUtil.toBean(bizSupplierTransportAddParam, BizSupplierTransport.class);
        this.save(bizSupplierTransport);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizSupplierTransportEditParam bizSupplierTransportEditParam) {
        //查询名称是否添加过
        long countName = this.count(new QueryWrapper<BizSupplierTransport>().lambda().eq(BizSupplierTransport::getTransportNo, bizSupplierTransportEditParam.getTransportNo())
                .eq(BizSupplierTransport::getSupplierId, bizSupplierTransportEditParam.getSupplierId())
                .ne(BizSupplierTransport::getId, bizSupplierTransportEditParam.getId())
                .eq(BizSupplierTransport::getDeleteFlag, BizSupplierTransportEnum.NOT_DELETE.getValue()));
        if(countName>0){
            throw new CommonException("供应商运输号已存在！");
        }
        BizSupplierTransport bizSupplierTransport = this.queryEntity(bizSupplierTransportEditParam.getId());
        BeanUtil.copyProperties(bizSupplierTransportEditParam, bizSupplierTransport);
        this.updateById(bizSupplierTransport);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizSupplierTransportIdParam> bizSupplierTransportIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizSupplierTransportIdParamList, BizSupplierTransportIdParam::getId));
    }

    @Override
    public BizSupplierTransport detail(BizSupplierTransportIdParam bizSupplierTransportIdParam) {
        return this.queryEntity(bizSupplierTransportIdParam.getId());
    }

    @Override
    public BizSupplierTransport queryEntity(String id) {
        BizSupplierTransport bizSupplierTransport = this.getById(id);
        if(ObjectUtil.isEmpty(bizSupplierTransport)) {
            throw new CommonException("供应商运输管理不存在，id值为：{}", id);
        }
        return bizSupplierTransport;
    }
}
